@@ -568,12 +568,16 @@ our %REVERSE_STAT = (
 our $LAST_PLAYOFF_GAME_INDEX = 417;
 our $LATE_START_IN_2012      = 1367330000;
 
+our $UNDRAFTED_PICK = 300;
+
 our @EXPORT = qw(
+	$LEAGUE_NAME
 	$REGULAR $PLAYOFF $LAST_PLAYOFF_GAME_INDEX $LATE_START_IN_2012 %DEFAULTED_GAMES
 	$FIRST_SEASON @LOCKOUT_SEASONS %FIRST_REPORT_SEASONS
 	$MAIN_GAME_FILE $SECONDARY_GAME_FILE
 	%TEAMS
 	$UNKNOWN_PLAYER_ID $BENCH_PLAYER_ID $COACH_PLAYER_ID $EMPTY_NET_ID
+	$UNDRAFTED_PICK
 	%VOCABULARY
 	%DATA_BY_SEASON %STAT_RECORD_FROM %REASONABLE_EVENTS
 	%PENALTY_POSSIBLE_NO_OFFENDER
@@ -585,6 +589,8 @@ our %ZERO_EVENT_GAMES = (
 	194320118 => 1,
 );
 
+our $LEAGUE_NAME = 'NHL';
+
 1;
 
 =head1 AUTHOR
